@@ -3,9 +3,11 @@ Main interface for cur service type definitions.
 
 Usage::
 
-    from mypy_boto3.cur.type_defs import DeleteReportDefinitionResponseTypeDef
+    ```python
+    from mypy_boto3_cur.type_defs import ReportDefinitionTypeDef
 
-    data: DeleteReportDefinitionResponseTypeDef = {...}
+    data: ReportDefinitionTypeDef = {...}
+    ```
 """
 import sys
 from typing import List
@@ -14,6 +16,7 @@ if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -21,16 +24,12 @@ else:
 
 
 __all__ = (
-    "DeleteReportDefinitionResponseTypeDef",
     "ReportDefinitionTypeDef",
+    "DeleteReportDefinitionResponseTypeDef",
     "DescribeReportDefinitionsResponseTypeDef",
     "PaginatorConfigTypeDef",
 )
 
-DeleteReportDefinitionResponseTypeDef = TypedDict(
-    "DeleteReportDefinitionResponseTypeDef", {"ResponseMessage": str}, total=False
-)
-
 _RequiredReportDefinitionTypeDef = TypedDict(
     "_RequiredReportDefinitionTypeDef",
     {
@@ -71,9 +70,13 @@ class ReportDefinitionTypeDef(_RequiredReportDefinitionTypeDef, _OptionalReportD
     pass
 
 
+DeleteReportDefinitionResponseTypeDef = TypedDict(
+    "DeleteReportDefinitionResponseTypeDef", {"ResponseMessage": str}, total=False
+)
+
 DescribeReportDefinitionsResponseTypeDef = TypedDict(
     "DescribeReportDefinitionsResponseTypeDef",
-    {"ReportDefinitions": List[ReportDefinitionTypeDef], "NextToken": str},
+    {"ReportDefinitions": List["ReportDefinitionTypeDef"], "NextToken": str},
     total=False,
 )
 
